cppzmq: Header-only C++ binding for libzmq
==========================================

Description
-----------

C++ binding for libzmq


License
-------

MIT


Upstream Contact
----------------

https://github.com/zeromq/cppzmq
